Compute a nonparametric estimate of (and efficient influence function for) the area under the longitudinal variable importance trajectory (AUTC) over a contiguous subset of the time series.
lvim_autc(
lvim,
indices = 1:length(lvim),
interpolator = "linear",
delta = 0,
...
)The lvim object, with point estimates, CIs, and p-values
related to the area under the trend in variable importance filled in.
an object of class lvim containing the cross-sectional
variable importance objects
a numeric vector indicating the contiguous subset of the time series
a string indicating the type of interpolator used to take the area under the trajectory
null hypothesis value
other arguments to be passed to the interpolator function